Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1075)

Unified Diff: src/crankshaft/arm/lithium-codegen-arm.cc

Issue 1409123003: [runtime] Avoid @@isConcatSpreadable lookup for fast path Array.prototype.concat (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: simplifications Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/crankshaft/arm/lithium-codegen-arm.cc
diff --git a/src/crankshaft/arm/lithium-codegen-arm.cc b/src/crankshaft/arm/lithium-codegen-arm.cc
index b61b6d8b7dc142102f7400c8cf2b64b6731307dc..35ebf887d8617ae5b704793d4144cc77c99d1366 100644
--- a/src/crankshaft/arm/lithium-codegen-arm.cc
+++ b/src/crankshaft/arm/lithium-codegen-arm.cc
@@ -3152,11 +3152,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
__ b(ne, &done);
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
// it needs to bail out.
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex);
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex);
__ ldr(result, FieldMemOperand(result, Cell::kValueOffset));
- __ cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid)));
+ __ cmp(result,
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid)));
DeoptimizeIf(ne, instr, Deoptimizer::kHole);
}
__ LoadRoot(result, Heap::kUndefinedValueRootIndex);
@@ -3152,11 +3152,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid.
+ // Otherwise
// it needs to bail out.
« no previous file with comments | « src/builtins.cc ('k') | src/crankshaft/arm64/lithium-codegen-arm64.cc » ('j') | src/isolate.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698